
# This algorithm extracts the SBP from an image
# and is based on the eqs by Bender & Moellenhof (1987).

from cfit import CFIT
import astropy.io.fits as pyfits
import os
import sys
import matplotlib.pyplot as plt
import numpy as np

if len(sys.argv) < 7:
  print 'List of input:'
  print 'P1 - Name of input frame'
  print 'P2 - Calibration constant (zero point mag)'
  print 'P3 - Galactic foreground extinction in the respective band'
  print 'P4 - True sky level'
  print 'P5 - Sky sigma'
  print 'P6 - Pixel scale (arcsec/pix)'
  print 'P7 - Gain (counts)'
  
  P1 = raw_input()
      
  image = pyfits.getdata(P1)
  NX = len(image[1])
  NY = len(image[:])

  P2 = float(raw_input())
  P3 = float(raw_input())
  P4 = float(raw_input())  
  P5 = float(raw_input())    
  P6 = float(raw_input())
  P7 = float(raw_input())

else:
  P1 = sys.argv[1]
      
  image = pyfits.getdata(P1)
  NX = len(image[1])
  NY = len(image[:])

  P2 = float(sys.argv[2])
  P3 = float(sys.argv[3])
  P4 = float(sys.argv[4])  
  P5 = float(sys.argv[5])    
  P6 = float(sys.argv[6])
  P7 = float(sys.argv[7])

# OPEN IMAGE IN DS9
os.system('ds9 %s &'%P1)


#central pixel
CENTER = []
var1, var2 = raw_input("Insert center coordinates (x,y - pix values): ").split(',')
var1, var2 = [float(var1), float(var2)]
CENTER.append(var1)
CENTER.append(var2)

#central intensity
CUTS = []
var = float(raw_input("Insert central intensity (counts): "))
var0 = P4/5.
CUTS.append(var0)
CUTS.append(var)

CSTEP = 0.02
NL    = 0

image = image.T

RANGE = [0,0]
#get secton to exclude in fit
if RANGE[0]<0. or RANGE[1]<0.:
      RANGE[0] = RANGE[0] + 360.
      RANGE[1] = RANGE[1] + 360.


#fit contours:
AS, BS, EVS, WFITS = CFIT(image,NX,NY,CUTS,CENTER,CSTEP,RANGE,NL)

radius = [] # arcsec
mu = []     # mag/arcsec2
sigma = []


file = open('%s_SBP.dat'%P1, 'w')
for i in range(len(AS)):
  radius.append(P6*np.sqrt(AS[i]*BS[i]))
  mu.append((-2.5*np.log10(EVS[i]/(P6*P6))) + P2 - P3) 
  
  val1 = (6.28/P6) * radius[i]
  ## NOTE: for SDSS data, since it has an offset of 1000, use instead:
  ## val2  = (P7*(EVS[i]+1000))/val1 + P5**2
  val2  = (P7*EVS[i])/val1 + P5**2
  val3 = val2*((2.5/(EVS[i]*2.3))**2)
  sigma.append(np.sqrt(val3))
  
  file.write('%s %s %s \n'%(radius[i],mu[i],sigma[i]))

print 'File %s_SBP.dat created with radius (arcsec), mu (mag/arcsec2) & sigma'%P1
file.close()  
  
fig,ax = plt.subplots()
ax.errorbar(radius,mu,yerr=sigma, fmt='o', color='k', markersize='5')
ax.set_xlim(0,max(radius)+5)
plt.gca().invert_yaxis()
ax.set_xlabel(r'$\rm Radius \, (arcsec)$')
ax.set_ylabel(r'$\rm \mu \, (mag/arcsec^2)$')
plt.show()
  
